@@ -1,7 +1,8 @@
 #' @title Plot Vote Distribution
-#' @description Plot distribution of votes for each sample in each class.
+#' @description For classification models, plot distribution of votes for each 
+#'   sample in each class.
 #' 
-#' @param rf an object inheriting from \code{\link{randomForest}}.
+#' @param x a \code{rfPermute} or \code{randomForest} model object.
 #' @param type either \code{area} for stacked continuous area plot or 
 #'   \code{bar} for discrete stacked bar chart. The latter is prefered for small 
 #'   numbers of cases. If not specified, a bar chart will be used if all 
@@ -16,6 +17,7 @@
 #' @author Eric Archer \email{eric.archer@@noaa.gov}
 #' 
 #' @examples
+#' library(randomForest)
 #' data(mtcars)
 #' 
 #' rf <- randomForest(factor(am) ~ ., mtcars)
@@ -23,12 +25,15 @@
 #' 
 #' @export
 #'
-plotVotes <- function(rf, type = NULL, freq.sep.line = TRUE, plot = TRUE) {  
-  if(rf$type != "classification") stop("'rf' must be a classification model")
+plotVotes <- function(x, type = NULL, freq.sep.line = TRUE, plot = TRUE) {  
+  rf <- as.randomForest(x)
+  if(rf$type == "regression") stop("'rf' must be of a classification model")
+  
   swfscMisc::plotAssignments(
-    rf$votes, rf$y, 
+    (rf$votes / rowSums(rf$votes)) * 100, 
+    rf$y, 
     type = type, 
-    ylab = "Proportion of votes", 
+    ylab = "Percent of votes", 
     freq.sep.line = freq.sep.line,
     plot = plot
   )
